<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:xs="http://www.w3.org/2001/XMLSchema"
    xmlns:ivdnt="http://www.ivdnt.org/xslt/namespaces"
    exclude-result-prefixes="xs"
    expand-text="yes"
    version="3.0">
    
    <xsl:function name="ivdnt:quote" as="xs:string">
        <xsl:param name="string" as="xs:string"/>
        <xsl:value-of select="'&quot;' || replace($string, '&quot;', '\\&quot;') || '&quot;'"/>
    </xsl:function>
    
    <xsl:function name="ivdnt:attributes2string" as="xs:string">
        <xsl:param name="attrs" as="attribute()*"/>
        <xsl:variable name="result" as="xs:string*"><xsl:for-each select="$attrs">{name(.) || '=' || ivdnt:quote(.)}</xsl:for-each></xsl:variable>
        <xsl:value-of select="if (count($result) gt 0) then ' ' || string-join($result, ' ') else ''"/>
    </xsl:function>
    
    <xsl:template match="results" mode="render-results">
        <xsl:message>started transforming elements results in mode render-results</xsl:message>
        <div class="gtb-results">
            <xsl:apply-templates select="statistics" mode="render-results"/>
            <!-- Note: the id 'gtb-result-table' is used on several places in this file and in js/gtb.js -->
            <table id="gtb-result-table">
                <colgroup>
                    <col class="gtb-wdbcol-line"/>
                    <col class="gtb-wdbcol-wdb"/>
                    <col class="gtb-wdbcol-modern_lemma"/>
                    <col class="gtb-wdbcol-lemma"/>
                    <col class="gtb-wdbcol-woordsoort"/>
                    <col class="gtb-wdbcol-betekenis"/>
                </colgroup>
                <thead>
                    <tr>
                        <td>Nr.</td>
                        <td>Wdb</td>
                        <td>Mod. Ned. trefwoord</td>
                        <td>Origineel trefwoord</td>
                        <td>Woordsoort</td>
                        <td>Betekenis</td>
                    </tr>
                </thead>
                <tbody>
                    <xsl:apply-templates select="result" mode="render-results"/>
                </tbody>
            </table>
        </div>
        <xsl:message>completed transforming elements results in mode render-results</xsl:message>
    </xsl:template>
    
    <xsl:template match="statistics" mode="render-results">
        <p class="gtb-statistics">
            <xsl:apply-templates mode="render-results"/>
        </p>
    </xsl:template>
    
    <xsl:template match="stat" mode="render-results">
        <xsl:variable name="documenten" as="xs:string" select="if (xs:integer(@count) eq 1) then 'document' else 'documenten'"/>        
        <span class="gtb-statcount" title="aantal hits: {@hits} in {@count} {$documenten}">{@count}</span>
        <xsl:if test="following-sibling::stat">
            <span class="gtb-statseparator"><xsl:text>&#32;-&#32;</xsl:text></span>
        </xsl:if>
    </xsl:template>
    
    <xsl:template match="result" mode="render-results">
        <!-- TODO Ignore attributes Homoniemnr and hits? -->
        <tr class="gtb-result-row">
            <xsl:apply-templates select="@line" mode="render-results"/>
            <xsl:apply-templates select="@Wdb" mode="render-results"/>
            <xsl:apply-templates select="@Modern_lemma" mode="render-results"/>
            <xsl:apply-templates select="@Lemma" mode="render-results"/>
            <xsl:apply-templates select="@Woordsoort" mode="render-results"/>
            <xsl:apply-templates select="@Betekenis" mode="render-results"/>
        </tr>
    </xsl:template>
    
    <xsl:template match="result/@*" mode="render-results">
        <td><xsl:value-of select="."/></td>
    </xsl:template>
    
</xsl:stylesheet>